@@ -48,7 +48,7 @@ class FeeVolume:
         "_sell_taker_count",
         "_result",
         "_reason",
-        "_message"
+        "_message",
     ]
 
     def __init__(
